__date__ = "2016-04-11"
__author__ = " Penghao Xiao"
__doc__ = "match_prim"
from monty.serialization import dumpfn, loadfn
import os, sys
from pymatgen.io.vasp.outputs import *
from pymatgen.core.structure import *
from pymatgen.core.composition import *
from pymatgen.analysis.structure_matcher import StructureMatcher, OrderDisorderElementComparator
import argparse


def read_PRIM(prim_file):
    with open(prim_file, 'r') as fp:
        fp.readline()
        a = float(fp.readline())
        avec = np.zeros((3, 3))
        avec[0] = map(float, fp.readline().split())
        avec[1] = map(float, fp.readline().split())
        avec[2] = map(float, fp.readline().split())
        avec *= a
        nsites = map(int, fp.readline().split())
        cooformat = fp.readline()
        if cooformat.strip() not in ["Direct", "direct"]:
            print("Error: This script can only handle direct coordinates!")
            print(cooformat)
            sys.exit()
        coords = []
        species = []
        for i in range(np.sum(nsites)):
            line = fp.readline()
            coords.append(map(float, line.split()[:3]))
            # FIXME: make sure that all coordinates are in [0:1]
            species.append(line.split()[3:])
        coords = np.array(coords)
    return (avec, coords, species)


if (__name__ == "__main__"):



    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter)

    parser.add_argument(
        "--PRIM_POSCAR",
        help="PRIM_POSCAR",
        type=str,
        default='PRIM.POSCAR')

    # parser.add_argument(
    #     "--PRIM",
    #     help="threshold",
    #     type=str,
    #     default='PRIM')


    args = parser.parse_args()
    # PRIM = args.PRIM
    PRIM_POSCAR = args.PRIM_POSCAR
    # (avec, coords, species) = read_PRIM(PRIM)


    # INPUT PARAM
    atol = 5
    l_tol = 0.3
    s_tol = 0.30
    s_prim = Structure.from_file(PRIM_POSCAR, primitive=True)
    s_prim.replace_species({'Cr':{'Cr': 1./3, 'Ni':1./3}})
    supercell_size = 'O'
    sm = StructureMatcher(primitive_cell=False,
            attempt_supercell=True,
            allow_subset=True,
            scale=True,
            supercell_size=supercell_size,
            comparator=OrderDisorderElementComparator(),
            stol=s_tol,
            ltol=l_tol,
            angle_tol=atol)

    #s = Structure.from_file('POSCAR_rotated.vasp')
    s = Structure.from_file('CONTCAR_Ofull.vasp')
    #print(s_prim)
    #print(s)
    #s = Structure.from_file('POSCAR')
    m = sm.get_supercell_matrix(s, s_prim)
    print(m)
    s_prim.make_supercell(m)

    sm = StructureMatcher(primitive_cell=False,
                          attempt_supercell=False,
                          allow_subset=True,
                          scale=True,
                          supercell_size=supercell_size,
                          comparator=OrderDisorderElementComparator(),
                          stol=s_tol,
                          ltol=l_tol,
                          angle_tol=atol)
    mapping = sm.get_mapping(s_prim, s)
    new_s = Structure.from_sites([s_prim[i] for i in mapping])
    for ti in range(len(new_s)):
        new_s[ti] = s[ti].specie
    #new_s.replace_species({'Al': {'Al': 2}})
    # xph: the following won't change any inter-site distance in s
    #new_s = sm.get_s2_like_s1(s_prim, s, include_ignored_species=True) 
    #new_s.to(filename='test.cif')
    #new_s.to(filename='test.POSCAR',fmt="POSCAR")
    pos4casm = Poscar(new_s)
    pos4casm.write_file("POS", vasp4_compatible=True)
    pos4casm.write_file("CONTCAR", vasp4_compatible=True)
    pos4casm.write_file("CONTCAR.vasp", vasp4_compatible=False)


