#!/usr/bin/env python

'''
set AFM configuration for spinel and run VASP
'''
from ase.calculators.vasp import Vasp
from ase.io import read, write
from ase.units import kB
import os
import sys

if os.path.exists('POSCAR'): 
   strfile='POSCAR'
else:
   "POSCAR is missing"

try:p = read(strfile)
except: "POSCAR read error" 

O_list = []
# set the initial magmom of tetrahedral sites to be negative
p222 = p*(2,2,2) # expand cell when the cell is very small
for i in range(len(p222)):
   if p222[i].symbol == 'O': O_list.append(i)
for i in range(len(p)):
   if p[i].symbol == 'O': 
      p[i].magmom=0
      continue
   if p[i].symbol == 'Al':
      p[i].symbol = 'Cr'
   dij = p222.get_distances(i, O_list, mic=True)
   CN = sum(dt < 3 for dt in dij)
   print CN
   if CN == 4: 
      if p[i].symbol == 'Cr': #Cr-Ni AFM is more stalbe, unlike Cr-Fe
         p[i].magmom = -3
      elif p[i].symbol == 'Ni':
         p[i].magmom = -2
   else: 
      if p[i].symbol == 'Cr':
         p[i].magmom = 3
      elif p[i].symbol == 'Ni':
         p[i].magmom = 2

calc = Vasp(prec = 'Normal',
            xc   = 'PBE',
            ediff = 1e-5,
            #kpts = (2,2,2),
            kpts = 15,
            lcharg = False,
            #lwave = False,
            isym = 0,
            ispin= 2,
            ncore = 18,
            nsim = 4,
            algo = 'Normal',
            lreal='Auto',
            #lreal='False',
            lplane = True,
            nelm  = 60,
            encut= 520,
            ismear = 0,
            sigma  = 0.05,
            lmaxmix   = 4,
            nsw    = 100,
            ibrion = 3,
            potim  = 0.1,
            ediffg = -0.03,
            ldau      = True,
            ldautype  = 2,
            ldauprint = 2,
            ldau_luj = {'O':{'L':-1,'U':0,'J':0},'Cr':{'L':2, 'U':3.5, 'J':0.0},'Ni':{'L':2, 'U':6.0, 'J':0.0}},
            isif = 3
              )

p.set_calculator(calc)
#write('POS1.bak',p, format='vasp')
print p.get_potential_energy()

